/**
 * @file   Background.js
 * @author simpart
 */

/**
 * @class mofron.comp.Background
 * @brief background component class
 */
mofron.comp.Background = class extends mofron.comp.Base {
    
    /**
     * initialize DOM contents
     *
     * @param vd : (mofron.util.Vdom) vdom object
     */
    initContents (vd, prm) {
        try {
            var div = new mofron.util.Vdom('div');
            div.setStyle('height'    , '100%');
            div.setStyle('width'     , '100%');
            div.setStyle('position'  , 'fixed');
            vd.addChild(div);
            this.target = this.getVdom().getChild(0);
            
            if (null === prm) {
                return;
            }
            if ('object' === (typeof prm)) {
                this.addChild(prm);
            }
        } catch (e) {
            console.error(e.stack);
            throw e;
        }
    }
    
    /**
     * button color getter/setter
     *
     * @param clr : (object) color (option)
     * @note for getter, do not specify parameters
     */
    color (clr) {
        try {
            var _clr = (clr === undefined) ? null : clr;
            if (null === _clr) {
                return this.getStyle().getStyle('background');
            }
            if ('object' != (typeof _clr)) {
                throw new Error('invalid parameter');
            }
            this.style('background', _clr.getStyle());
        } catch (e) {
            console.error(e.stack);
            throw e;
        }
    }
    
    /**
     * set shadow style to side
     *
     * @param val : (number) shadow length
     * @return box-shadow value
     * @note for getter, do not specify parameters
     */
    shadow (val) {
        try {
            var _val = (val === undefined) ? null : val;
            if (null === _val) {
                return this.getStyle().getStyle('box-shadow');
            }
            if ('number' != (typeof _val)) {
                throw new Error('invalid parameter');
            }
            this.style('box-shadow', '0px '+ val/2 + 'px '+ val +'px '+ '0px gray');
        } catch (e) {
            console.error(e.stack);
            throw e;
        }
    }
}
